import { iSimpleTableRow, iSimpleTableField } from "@asup/simple-table";
import { JSX } from "react";
/**
 * Interface for data set row
 */
export interface ItemDataRow extends iSimpleTableRow {
    /**
     * Number of the row in the data set
     */
    __rowNumber: number;
    /**
     * True if the row has been deleted
     */
    __isDeleted: boolean;
}
/**
 * Item type
 */
export enum eItemType {
    string = "string",
    integer = "integer",
    float = "float",
    date = "Date",
    time = "Time",
    datetime = "DateTime"
}
/**
 * Item (variable) inside a DatasetJson object
 */
interface iDatasetJsonItem extends iSimpleTableRow {
    /**
     * Item unique identifier
     */
    OID: string;
    /**
     * Item name
     */
    name: string;
    /**
     * Item label
     */
    label: string;
    /**
     * Item type
     */
    type: eItemType;
    /**
     * Item length (for strings)
     */
    length?: number;
}
export class DatasetJsonItemClass {
    /**
     * Unique identifier
     */
    get OID(): string;
    /**
     * Item name
     */
    get name(): string;
    /**
     * Item label
     */
    get label(): string;
    /**
     * Item type
     */
    get type(): eItemType;
    /**
     * Assigned item length for strings
     */
    get length(): number | undefined;
    /**
     * Data stored in the clas
     */
    get data(): iDatasetJsonItem;
    /**
     * Stringified version of the class
     */
    get toString(): string;
    /**
     * Create new data item class
     * @param newItem New data item information
     */
    constructor(newItem: iDatasetJsonItem);
    /**
     * Return JSX span with the class name
     */
    get component(): JSX.Element;
}
/**
 * CDISC implementation of Dataset JSON typescript interface
 */
export interface CdiscDatasetJson {
    clinicalData: {
        studyOID: string;
        metaDataVersionOID: string;
        itemGroupData: {
            [key: string]: {
                records: number;
                name: string;
                label: string;
                items: {
                    OID: string;
                    name: string;
                    label: string;
                    type: eItemType;
                    length?: number;
                }[];
                itemData: (string | number | null)[][];
            };
        };
    };
}
/**
 * Typescript class for a CDISC data set JSON object
 */
declare class DatasetJsonClass {
    /**
     * Error text after internal error
     */
    get errorText(): string;
    /**
     * studyOID attibute
     */
    get studyOID(): string;
    /**
     * Sets value of studyOID
     */
    set studyOID(newValue: string);
    get metaDataVersionOID(): string;
    /**
     * Data set name
     */
    get name(): string;
    /**
     * Data set name
     */
    set name(newValue: string);
    /**
     * Data set label
     */
    get label(): string;
    /**
     * Data set label
     */
    set label(newValue: string);
    /**
     * Number of records in the data set
     */
    get records(): number;
    /**
     * Items (variables) in the data set
     */
    get items(): DatasetJsonItemClass[];
    /**
     * Items (variables) in the data set
     */
    set items(newItems: (iDatasetJsonItem | DatasetJsonItemClass)[]);
    get simpleTableFields(): iSimpleTableField[];
    /**
     * Add new item (variable) to the data set
     * @param newItem Add data set item definition to the data set
     * @returns true is successful, false (& sets errorText) is there is an error
     */
    addItem(newItem: DatasetJsonItemClass | iDatasetJsonItem): boolean;
    /**
     * Removes an item (variable) from the data set and the associated data
     * @param oldItemName Name of the item to remove
     */
    removeItem(oldItemName: string): void;
    _itemData: ItemDataRow[];
    /**
     * Data stored in the data set
     */
    get itemData(): iSimpleTableRow[];
    /**
     * Data stored in the data set
     */
    set itemData(newItemDataRows: iSimpleTableRow[]);
    /**
     * Add single row to the data
     * @param newItemDataRow New row data
     * @returns true is successful, false (& sets errorText) is there is an error
     */
    addItemData(newItemDataRow: iSimpleTableRow): boolean;
    /**
     * Remove a single row from the data
     * @param rowNumber Row number to remove
     * @returns true is successful, false (& sets errorText) is there is an error
     */
    removeItemData(rowNumber: number): boolean;
    /**
     * Create new DatasetJson class
     * @param newJson Raw dataset JSON
     */
    constructor(newJson: CdiscDatasetJson);
}
interface SummaryTableGeneratorProps {
    dataset: DatasetJsonClass;
}
export const SummaryTableGenerator: ({ dataset }: SummaryTableGeneratorProps) => JSX.Element;

//# sourceMappingURL=dataset-json-handler.d.ts.map
